## Cells derived primarily from endoderm

### Exocrine secretory epithelial cells.

-   [Brunner's gland](Brunner's_gland "wikilink") cell in duodenum ([enzymes](enzyme "wikilink") and [alkaline mucus](alkaline_mucus "wikilink"))
-   Insulated [goblet cell](goblet_cell "wikilink") of [respiratory](respiratory_tract "wikilink") and [digestive](Gastrointestinal_tract "wikilink") tracts (mucus secretion)
-   Stomach
    -   [Foveolar cell](Gastric_glands#Types_of_cell "wikilink") (mucus secretion)
    -   [Chief cell](Gastric_glands#Types_of_cell "wikilink") ([pepsinogen](pepsinogen "wikilink") secretion)
    -   [Parietal cell](Gastric_glands#Types_of_cell "wikilink") ([hydrochloric acid](hydrochloric_acid "wikilink") secretion)
-   [Pancreatic acinar](Pancreas#Histology "wikilink") cell ([bicarbonate](bicarbonate "wikilink") and [digestive enzyme](digestive_enzyme "wikilink") secretion)
-   [Paneth cell](Paneth_cell "wikilink") of small [intestine](intestine "wikilink") ([lysozyme](lysozyme "wikilink") secretion)
-   Type II [pneumocyte](pneumocyte "wikilink") of [lung](human_lung "wikilink") ([surfactant](surfactant "wikilink") secretion)
-   [Club cell](Club_cell "wikilink") of lung

### Barrier cells

-   Type I [pneumocyte](pneumocyte "wikilink") (lung)
-   [Gall bladder epithelial cell](Gallbladder#Microanatomy "wikilink")
-   [Centroacinar cell](Centroacinar_cell "wikilink") (pancreas)
-   [Intercalated duct](Intercalated_duct "wikilink") cell (pancreas)
-   Intestinal [brush border](brush_border "wikilink") cell (with [microvilli](microvilli "wikilink"))

### Hormone-secreting cells

-   [Enteroendocrine cell](Enteroendocrine_cell "wikilink")
    -   K cell (secretes [gastric inhibitory peptide](gastric_inhibitory_peptide "wikilink"))
    -   L cell (secretes [glucagon-like peptide-1](glucagon-like_peptide-1 "wikilink"), [ peptide YY<sub>3-36</sub>](peptide_YY "wikilink"), [oxyntomodulin](oxyntomodulin "wikilink"), and [glucagon-like peptide-2](glucagon-like_peptide-2 "wikilink"))
    -   I cell (secretes [cholecystokinin](cholecystokinin "wikilink") (CCK))
    -   G cell (secretes [gastrin](gastrin "wikilink"))
    -   [Enterochromaffin cell](Enterochromaffin_cell "wikilink") (secretes [serotonin](serotonin "wikilink"))
    -   [Enterochromaffin-like cell](Enterochromaffin-like_cell "wikilink") (secretes [histamine](histamine "wikilink"))
    -   N cell (secretes [neurotensin](neurotensin "wikilink"))
    -   S cell (secretes [secretin](secretin "wikilink"))
    -   D cell (secretes [somatostatin](somatostatin "wikilink"))
    -   Mo cell (or M cell) (secretes [motilin](motilin "wikilink"))
    -   other hormones secreted: [vasoactive intestinal peptide](vasoactive_intestinal_peptide "wikilink"), [substance P](substance_P "wikilink"), [alpha](alpha-endorphin "wikilink") and [gamma-endorphin](gamma-endorphin "wikilink"), [bombesin](bombesin "wikilink")
-   [Thyroid gland](Thyroid_gland "wikilink") cells
    -   [Thyroid epithelial cell](Thyroid_epithelial_cell "wikilink")
    -   [Parafollicular cell](Parafollicular_cell "wikilink")
-   [Parathyroid gland](Parathyroid_gland "wikilink") cells
    -   [Parathyroid chief cell](Parathyroid_chief_cell "wikilink")
    -   [Oxyphil cell](Oxyphil_cell_(parathyroid) "wikilink")
-   [Pancreatic islets](Pancreatic_islets "wikilink") (islets of Langerhans)
    -   [Alpha cell](Alpha_cell "wikilink") (secretes [glucagon](glucagon "wikilink"))
    -   [Beta cell](Beta_cell "wikilink") (secretes [insulin](insulin "wikilink") and [amylin](amylin "wikilink"))
    -   [Delta cell](Delta_cell "wikilink") (secretes [somatostatin](somatostatin "wikilink"))
    -   [Epsilon cell](Epsilon_cell "wikilink") (secretes [ghrelin](ghrelin "wikilink"))
    -   [PP cell](PP_cell "wikilink") (gamma cell) (secretes [pancreatic polypeptide](pancreatic_polypeptide "wikilink"))

## Cells derived primarily from ectoderm

### Exocrine secretory epithelial cells

-   [Salivary gland](Salivary_gland#Microanatomy "wikilink") mucous cell
-   [Salivary gland](Salivary_gland#Microanatomy "wikilink") serous cell
-   [Von Ebner's gland](Von_Ebner's_glands "wikilink") cell in tongue (washes [taste buds](taste_bud "wikilink"))
-   [Mammary gland](Mammary_gland "wikilink") cell ([milk](milk "wikilink") secretion)
-   [Lacrimal gland cell](Lacrimal_gland_cell "wikilink") ([tear](Tears "wikilink") secretion)
-   [Ceruminous gland](Ceruminous_glands "wikilink") cell in [ear](ear "wikilink") ([earwax](earwax "wikilink") secretion)
-   [Eccrine sweat gland](Eccrine_sweat_glands "wikilink") dark cell (glycoprotein secretion)
-   [Eccrine sweat gland](Eccrine_sweat_glands "wikilink") clear cell (small molecule secretion)
-   [Apocrine sweat gland](Apocrine_sweat_glands "wikilink") cell (odoriferous secretion, sex-hormone sensitive)
-   [Gland of Moll](Glands_of_Moll "wikilink") cell in eyelid (specialized [sweat gland](sweat_gland "wikilink"))
-   [Sebaceous gland](Sebaceous_gland "wikilink") cell (lipid-rich [sebum](sebum "wikilink") secretion)
-   [Bowman's gland](Bowman's_gland "wikilink") cell in [nose](human_nose "wikilink") (washes [olfactory](olfactory "wikilink") epithelium)

### Hormone-secreting cells

-   Anterior/Intermediate [pituitary](Pituitary_gland "wikilink") cells
    -   [Corticotropes](Corticotrope "wikilink")
    -   [Gonadotropes](Gonadotrope "wikilink")
    -   [Lactotropes](Lactotrope "wikilink")
    -   [Melanotropes](Melanotroph "wikilink")
    -   [Somatotropes](Somatotrope "wikilink")
    -   [Thyrotropes](Thyrotrope "wikilink")
-   [Magnocellular neurosecretory cells](Magnocellular_neurosecretory_cell "wikilink"), secrete [oxytocin](oxytocin "wikilink") and [vasopressin](vasopressin "wikilink")
-   [Parvocellular neurosecretory cells](Parvocellular_neurosecretory_cell "wikilink"), secrete [thyrotropin-releasing hormone](thyrotropin-releasing_hormone "wikilink") (TRH), [corticotropin-releasing hormone](corticotropin-releasing_hormone "wikilink") (CRH), vasopressin, oxytocin,
    [neurotensin](neurotensin "wikilink"), and [prolactin](prolactin "wikilink")
-   [Chromaffin cells](Chromaffin_cell "wikilink") ([adrenal gland](adrenal_gland "wikilink"))

### Epithelial cells

-   [Keratinocyte](Keratinocyte "wikilink") (differentiating [epidermal](Epidermis_(skin) "wikilink") cell)
-   Epidermal [basal cell](Epidermis#Cellular_components "wikilink") ([stem cell](stem_cell "wikilink"))
-   [Melanocyte](Melanocyte "wikilink")
-   [Trichocyte](Trichocyte_(human) "wikilink") (gives rise to hair and nail cells)
    -   [Medullary](Medulla_(hair) "wikilink") hair shaft cell
    -   [Cortical](Cortex_(hair) "wikilink") hair shaft cell
    -   [Cuticular](Cuticle_(hair) "wikilink") hair shaft cell
    -   [Huxley's layer](Huxley's_layer "wikilink") hair root sheath cell
    -   [Henle's layer](Henle's_layer "wikilink") hair root sheath cell
    -   [Outer root sheath](Outer_root_sheath "wikilink") hair cell
-   Surface [epithelial cell](epithelial_cell "wikilink") of [cornea](cornea "wikilink"), [tongue](tongue "wikilink"), [mouth](mouth "wikilink"), [nasal cavity](nasal_cavity "wikilink"), distal [anal canal](anal_canal "wikilink"), distal [urethra](urethra "wikilink"), and distal
    [vagina](vagina "wikilink")
-   basal cell (stem cell) of cornea, tongue, mouth, nasal cavity, distal anal canal, distal urethra, and distal vagina
-   [Intercalated duct](Intercalated_duct "wikilink") cell (salivary glands)
-   [Striated duct](Striated_duct "wikilink") cell (salivary glands)
-   [Lactiferous duct](Lactiferous_duct "wikilink") cell (mammary glands)
-   [Ameloblast](Ameloblast "wikilink") (deposit [tooth enamel](tooth_enamel "wikilink"))

### Oral cells

-   [Odontoblast](Odontoblast "wikilink") (tooth [dentin](dentin "wikilink") formation)
-   [Cementoblast](Cementoblast "wikilink") (tooth [cementum](cementum "wikilink") formation)

### Nervous system

There are nerve cells, also known as [neurons](neuron "wikilink"), present in our human body. They are branched out. These cells make up [nervous tissue](nervous_tissue "wikilink"). A neuron consists of a cell body with a nucleus and cytoplasm, from which long thin hair-like parts arise.

#### Sensory transducer cells

-   [Auditory inner hair cells](Hair_cell "wikilink") of [organ of Corti](organ_of_Corti "wikilink")
-   [Auditory outer hair cells](Hair_cell "wikilink") of [organ of Corti](organ_of_Corti "wikilink")
-   Basal cells of [olfactory epithelium](olfactory_epithelium "wikilink") (stem cell for olfactory neurons)
-   Cold-sensitive primary [sensory neurons](sensory_neuron "wikilink")
-   Heat-sensitive primary [sensory neurons](sensory_neuron "wikilink")
-   [Merkel cells](Merkel_cell "wikilink") of epidermis
-   [Olfactory receptor neurons](Olfactory_receptor_neuron "wikilink")
-   Pain-sensitive primary [sensory neurons](sensory_neuron "wikilink")
-   [Photoreceptor cells](Photoreceptor_cell "wikilink") of [retina](retina "wikilink") in [eye](human_eye "wikilink"):
    -   Photoreceptor [rod cells](rod_cell "wikilink")
    -   Photoreceptor blue-sensitive [cone cells](cone_cell "wikilink") of eye
    -   Photoreceptor green-sensitive [cone cells](cone_cell "wikilink") of eye
    -   Photoreceptor red-sensitive [cone cells](cone_cell "wikilink") of eye
-   [Proprioceptive](Proprioceptive "wikilink") primary [sensory neurons](sensory_neuron "wikilink")
-   Touch-sensitive primary [sensory neurons](sensory_neuron "wikilink")
-   [Chemoreceptor](Chemoreceptor "wikilink") [glomus cells](glomus_cell "wikilink") of [carotid body cell](carotid_body "wikilink") (blood pH sensor)
-   [Outer hair cells](Hair_cell "wikilink") of [vestibular system](vestibular_system "wikilink") of ear (acceleration and gravity)
-   [Inner hair cells](Hair_cell "wikilink") of [vestibular system](vestibular_system "wikilink") of ear (acceleration and gravity)
-   [Taste receptor cells](Taste_receptor "wikilink") of [taste bud](taste_bud "wikilink")

#### Autonomic neuron cells

-   [Cholinergic neurons](Cholinergic_neuron "wikilink") (various types)
-   [Adrenergic](Adrenergic "wikilink") neural cells (various types)
-   [Peptidergic](Peptidergic "wikilink") neural cells (various types)

#### Sense organ and peripheral neuron supporting cells

-   Inner pillar cells of [organ of Corti](organ_of_Corti "wikilink")
-   Outer pillar cells of organ of Corti
-   Inner phalangeal cells of organ of Corti
-   Outer phalangeal cells of organ of Corti
-   Border cells of organ of Corti
-   [Hensen's cells](Hensen's_cell "wikilink") of organ of Corti
-   Vestibular apparatus supporting cells
-   Taste bud supporting cells
-   Olfactory epithelium supporting cells
-   [Olfactory ensheathing cells](Olfactory_ensheathing_cell "wikilink")
-   [Schwann cells](Schwann_cell "wikilink")
-   [Satellite glial cells](Satellite_glial_cell "wikilink")
-   Enteric glial cells

#### Central nervous system neurons and [glial cells](glial_cell "wikilink")

-   [Neuron](Neuron "wikilink") cells (large variety of types, still poorly classified)
    -   [Interneurons](Interneuron "wikilink")
        -   [Basket cells](Basket_cell "wikilink")
        -   [Cartwheel cells](Cartwheel_cell "wikilink")
        -   [Stellate cells](Stellate_cell "wikilink")
        -   [Golgi cells](Golgi_cell "wikilink")
        -   [Granule cells](Granule_cell "wikilink")
        -   [Lugaro cells](Lugaro_cell "wikilink")
        -   [Unipolar brush cells](Unipolar_brush_cell "wikilink")
        -   [Martinotti cells](Martinotti_cell "wikilink")
        -   [Chandelier cells](Chandelier_cell "wikilink")
        -   [Cajal–Retzius cells](Cajal–Retzius_cell "wikilink")
        -   [Double-bouquet cells](Double-bouquet_cell "wikilink")
        -   [Neurogliaform cells](Neurogliaform_cell "wikilink")
        -   [Retina horizontal cells](Retina_horizontal_cell "wikilink")
        -   [Amacrine cells](Amacrine_cell "wikilink")
            -   [Starburst amacrine cells](Starburst_amacrine_cell "wikilink")
        -   [Spinal interneurons](Spinal_interneuron "wikilink")
            -   [Renshaw cells](Renshaw_cell "wikilink")
    -   Principal cells
        -   [Spindle neurons](Spindle_neuron "wikilink")
        -   [Fork neurons](Fork_neuron "wikilink")
        -   [Pyramidal cells](Pyramidal_cell "wikilink")
            -   [Place cells](Place_cell "wikilink")
            -   [Grid cells](Grid_cell "wikilink")
            -   [Speed cells](Speed_cell "wikilink")
            -   [Head direction cells](Head_direction_cell "wikilink")
            -   [Betz cells](Betz_cell "wikilink")
        -   [Stellate cells](Stellate_cell "wikilink")
            -   [Boundary cells](Boundary_cell "wikilink")
        -   [Bushy cells](Bushy_cell "wikilink")
        -   [Purkinje cells](Purkinje_cell "wikilink")
        -   [Medium spiny neurons](Medium_spiny_neuron "wikilink")
-   [Astrocytes](Astrocyte "wikilink")
-   [Oligodendrocytes](Oligodendrocyte "wikilink")
-   [Ependymal cells](Ependymal_cell "wikilink")
    -   [Tanycytes](Tanycyte "wikilink")
-   [Pituicytes](Pituicyte "wikilink")

#### Lens cells

-   [Anterior lens epithelial cell](Anterior_lens_epithelial_cell "wikilink")
-   [Crystallin-containing lens fiber cell](Crystallin-containing_lens_fiber_cell "wikilink")

## Cells derived primarily from mesoderm

### Metabolism and storage cells

-   [Adipocytes](Adipocytes "wikilink"):
    -   [White fat cell](White_adipose_tissue "wikilink")
    -   [Brown fat cell](Brown_fat "wikilink")
-   [Liver lipocyte](Liver_lipocyte "wikilink")

### Secretory cells

-   Cells of the [Adrenal cortex](Adrenal_cortex "wikilink")
    -   Cells of the Zona glomerulosa produce [mineralocorticoids](mineralocorticoid "wikilink")
    -   Cells of the Zona fasciculata produce [glucocorticoids](glucocorticoid "wikilink")
    -   Cells of the Zona reticularis produce [androgens](androgen "wikilink")
-   [Theca interna cell](Theca_interna_cell "wikilink") of [ovarian follicle](ovarian_follicle "wikilink") secreting [estrogen](estrogen "wikilink")
-   Corpus luteum cell of ruptured ovarian follicle secreting [progesterone](progesterone "wikilink")
    -   [Granulosa lutein cells](Granulosa_lutein_cell "wikilink")
    -   [Theca lutein cells](Theca_lutein_cell "wikilink")
-   [Leydig cell](Leydig_cell "wikilink") of [testes](testes "wikilink") secreting [testosterone](testosterone "wikilink")
-   [Seminal vesicle](Seminal_vesicle "wikilink") cell (secretes seminal [fluid](fluid "wikilink") components, including [fructose](fructose "wikilink") for swimming [sperm](Spermatozoon "wikilink"))
-   [Prostate gland](Prostate_gland "wikilink") cell (secretes seminal fluid components)
-   [Bulbourethral gland](Bulbourethral_gland "wikilink") cell ([mucus](mucus "wikilink") secretion)
-   [Bartholin's gland](Bartholin's_gland "wikilink") cell ([vaginal lubricant](vaginal_lubricant "wikilink") secretion)
-   [Gland of Littre](Urethral_gland "wikilink") cell (mucus secretion)
-   [Uterus](Uterus "wikilink") [endometrium](endometrium "wikilink") cell ([carbohydrate](carbohydrate "wikilink") secretion)
-   [Juxtaglomerular cell](Juxtaglomerular_cell "wikilink") ([renin](renin "wikilink") secretion)
-   [Macula densa cell](Macula_densa_cell "wikilink") of kidney
-   [Peripolar cell](Peripolar_cell "wikilink") of kidney
-   [Mesangial cell](Mesangial_cell "wikilink") of kidney

### Barrier cells

#### Urinary system

-   [Parietal epithelial cell](Bowman's_capsule#Anatomy "wikilink")
-   [Podocyte](Podocyte "wikilink")
-   [Proximal tubule brush border cell](Proximal_tubule#Brush_border_cell "wikilink")
-   [Loop of Henle thin segment cell](Thin_segment#Histology "wikilink")
-   [Kidney distal tubule cell](Kidney_distal_tubule_cell "wikilink")
-   [Kidney collecting duct cell](Collecting_duct_system "wikilink")
    -   [Principal cell](Collecting_duct_system#Principal_cells "wikilink")
    -   [Intercalated cell](Collecting_duct_system#Intercalated_cells "wikilink")
-   [Transitional epithelium](Transitional_epithelium "wikilink") (lining [urinary bladder](urinary_bladder "wikilink"))

#### Reproductive system

-   Duct cell (of [seminal vesicle](seminal_vesicle "wikilink"), [prostate gland](prostate_gland "wikilink"), etc.)
-   [Efferent ducts](Efferent_ducts "wikilink") cell
-   [Epididymal principal cell](Epididymis#Histology "wikilink")
-   [Epididymal basal cell](Epididymis#Histology "wikilink")

#### Circulatory system

-   [Endothelial cells](Endothelial_cells "wikilink")

### Extracellular matrix cells

-   Planum semilunatum epithelial cell of [vestibular system](vestibular_system "wikilink") of ear (proteoglycan secretion)
-   [Organ of Corti](Organ_of_Corti "wikilink") interdental epithelial cell (secreting tectorial membrane covering hair cells)
-   [Loose connective tissue](Loose_connective_tissue "wikilink") [fibroblasts](fibroblast "wikilink")
-   [Corneal](Cornea "wikilink") fibroblasts ([corneal keratocytes](corneal_keratocyte "wikilink"))
-   [Tendon fibroblasts](Tendon_cell "wikilink")
-   [Bone marrow](Bone_marrow#Stroma "wikilink") [reticular tissue](reticular_tissue "wikilink") [fibroblasts](fibroblast "wikilink")
-   Other nonepithelial [fibroblasts](fibroblast "wikilink")
-   [Pericyte](Pericyte "wikilink")
    -   [Hepatic stellate cell](Hepatic_stellate_cell "wikilink") (Ito cell)
-   [Nucleus pulposus cell](Nucleus_pulposus_cell "wikilink") of [intervertebral disc](intervertebral_disc "wikilink")
-   [Hyaline cartilage](Hyaline_cartilage "wikilink") [chondrocyte](chondrocyte "wikilink")
-   [Fibrocartilage](Fibrocartilage "wikilink") [chondrocyte](chondrocyte "wikilink")
-   [Elastic cartilage](Elastic_cartilage "wikilink") [chondrocyte](chondrocyte "wikilink")
-   [Osteoblast](Osteoblast "wikilink")/[osteocyte](osteocyte "wikilink")
-   [Osteoprogenitor cell](Osteoblast#Osteogenesis "wikilink") (stem cell of [osteoblasts](osteoblast "wikilink"))
-   [Hyalocyte](Hyalocyte "wikilink") of [vitreous body](vitreous_body "wikilink") of eye
-   [Stellate cell](Stellate_cell "wikilink") of perilymphatic space of ear
-   [Pancreatic stellate cell](Pancreatic_stellate_cell "wikilink")

Note: [Cephalic](Cephalic "wikilink") connective tissue and bones are derived from the [Cranial neural crest](Cranial_neural_crest "wikilink") which comes from the [ectoderm](ectoderm "wikilink") [germ layer](germ_layer "wikilink")

### Contractile cells

-   [Skeletal muscle](Skeletal_muscle "wikilink") cells
    -   [Red skeletal muscle cell](Myocyte#Fiber_typing "wikilink") (slow twitch)
    -   [White skeletal muscle cell](Myocyte#Fiber_typing "wikilink") (fast twitch)
    -   [Intermediate skeletal muscle cell](Myocyte#Fiber_typing "wikilink")
    -   [Nuclear bag cell](Nuclear_bag_fiber "wikilink") of [muscle spindle](muscle_spindle "wikilink")
    -   [Nuclear chain cell](Nuclear_chain_cell "wikilink") of [muscle spindle](muscle_spindle "wikilink")
    -   [Myosatellite cell](Myosatellite_cell "wikilink") (stem cell)
-   [Cardiac muscle](Cardiac_muscle "wikilink") cells
    -   [Cardiac muscle cell](Cardiac_muscle_cell "wikilink")
    -   [SA node cell](Cardiac_pacemaker#Primary_(SA_node) "wikilink")
    -   [Purkinje fiber](Purkinje_fiber "wikilink") cell
-   [Smooth muscle cell](Smooth_muscle_cell "wikilink") (various types)
-   [Myoepithelial cell](Myoepithelial_cell "wikilink") of [iris](Iris_(anatomy) "wikilink")
-   [Myoepithelial cell](Myoepithelial_cell "wikilink") of [exocrine glands](exocrine_glands "wikilink")

### Blood and immune system cells

-   [Erythrocyte](Erythrocyte "wikilink") (red blood cell) and precursor erythroblasts
-   [Megakaryocyte](Megakaryocyte "wikilink") ([platelet](platelet "wikilink") precursor)
-   [Platelets](Platelets "wikilink") if considered distinct cells, currently there's debate on the subject.
-   [Monocyte](Monocyte "wikilink") (white blood cell)
-   Connective tissue [macrophage](macrophage "wikilink") (various types)
-   Epidermal [Langerhans cell](Langerhans_cell "wikilink")
-   [Osteoclast](Osteoclast "wikilink") (in bone)
-   [Dendritic cell](Dendritic_cell "wikilink") (in [lymphoid tissues](lymphoid_tissue "wikilink"))
-   [Microglial cell](Microglial_cell "wikilink") (in [central nervous system](central_nervous_system "wikilink"))
-   [Neutrophil granulocyte](Neutrophil_granulocyte "wikilink") and precursors ([myeloblast](myeloblast "wikilink"), [promyelocyte](promyelocyte "wikilink"), [myelocyte](myelocyte "wikilink"), [metamyelocyte](metamyelocyte "wikilink"))
-   [Eosinophil granulocyte](Eosinophil_granulocyte "wikilink") and precursors
-   [Basophil granulocyte](Basophil_granulocyte "wikilink") and precursors
-   [Mast cell](Mast_cell "wikilink")
-   [Helper T cell](Helper_T_cell "wikilink")
-   [Regulatory T cell](Regulatory_T_cell "wikilink")
-   [Cytotoxic T cell](Cytotoxic_T_cell "wikilink")
-   [Natural killer T cell](Natural_killer_T_cell "wikilink")
-   [B cell](B_cell "wikilink")
-   [Plasma cell](Plasma_cell "wikilink")
-   [Natural killer cell](Natural_killer_cell "wikilink")
-   [Hematopoietic stem cells](Hematopoietic_stem_cell "wikilink") and [committed progenitors](Progenitor_cells "wikilink") for the [blood](blood "wikilink") and [immune system](immune_system "wikilink") (various types)

### Germ cells (primordially not)

-   [Oogonium](Ovum "wikilink")/[Oocyte](Oocyte "wikilink")
-   [Spermatid](Spermatid "wikilink")
-   [Spermatocyte](Sperm "wikilink")
-   [Spermatogonium cell](Spermatogonium_cell "wikilink") (stem cell for spermatocyte)
-   [Spermatozoon](Sperm "wikilink")

### [Nurse cell](Nurse_cell "wikilink")

-   [Granulosa cell](Granulosa_cell "wikilink") (in ovaries)
-   [Sertoli cell](Sertoli_cell "wikilink") (in testis)
-   [Epithelial reticular cell](Epithelial_reticular_cell "wikilink") (in thymus)

### Interstitial cells

-   [Interstitial kidney cells](Interstitial_kidney_cells "wikilink")
